function datao = realft(datai,n,isign)
%
%  This routine is a direct conversion of realft.f 
%  from Fortran to Matlab.
%  The original Fortran code is from Numerical Recipes.
%   translation:  David J. Keffer
%   University of Tennessee
%   dkeffer@utk.edu
%   code translated:  March 5, 2014
%
%  code usage:  datao = realft(datai,n,isign)
%
%  datai = input data
%  n = length of input data
%  isign = -1 for transformation from r to q
%  isign =  1 for transformation from q to r
%  datao = output data
%
datao = datai;
%
%  input program constants
%
theta=3.141592653589793d0/(n/2);
c1 = 0.50;
if (isign == 1)
   c2 = -0.5;
   datao =  four1(datao,n/2,+1);
else
   c2 = 0.5;
   theta=-theta;
end
wpr=-2.00*sin(0.50*theta)^2;
wpi=sin(theta);
wr=1.00+wpr;
wi=wpi;
n2p3=n+3;
for i = 2:1:n/4
   i1=2*i-1;
   i2=i1+1;
   i3=n2p3-i2;
   i4=i3+1;
   wrs=wr;
   wis=wi;
   h1r=c1*(datao(i1)+datao(i3));
   h1i=c1*(datao(i2)-datao(i4));
   h2r=-c2*(datao(i2)+datao(i4));
   h2i=c2*(datao(i1)-datao(i3));
   datao(i1)=h1r+wrs*h2r-wis*h2i;
   datao(i2)=h1i+wrs*h2i+wis*h2r;
   datao(i3)=h1r-wrs*h2r+wis*h2i;
   datao(i4)=-h1i+wrs*h2i+wis*h2r;
   wtemp=wr;
   wr=wr*wpr-wi*wpi+wr;
   wi=wi*wpr+wtemp*wpi+wi;
end
%
if (isign == 1) 
   h1r=datao(1);
   datao(1)=h1r+datao(2);
   datao(2)=h1r-datao(2);
else
   h1r=datao(1);
   datao(1)=c1*(h1r+datao(2));
   datao(2)=c1*(h1r-datao(2));
   datao =  four1(datao,n/2,-1);
end
